@@ -6,71 +6,29 @@ use POSIX;
 use List::Util;
 use Data::Dumper qw(Dumper);
 use Exporter qw(import);
-our @EXPORT_LIST = qw(
-    incr        reduces   flatten
-    drop_right  drop      take_right  take
-    assoc       maps      decr        chain
-    first       end       subarray    partial
-    __          find      filter      some
-    none        uniq      bool        spread
-    len         to_keys   to_vals     is_array
-    is_hash     every     noop        identity
-    is_empty    is_sub    flow        eql
-    to_pairs    for_each  apply       get
-    second      range     pops        pushes
-    shifts      unshifts  once
+our @EXPORT_OK = qw(
+    incr        reduces  flatten
+    drop_right  drop     take_right  take
+    assoc       maps     decr        chain
+    first       end      subarray    partial
+    __          find     filter      some
+    none        uniq     bool        spread
+    len         to_keys  to_vals     is_array
+    is_hash     every    noop        identity
+    is_empty    is_sub   flow        eql
+    to_pairs    for_each apply       get
+    second      range    pops        pushes
+    shifts      unshifts once
 );
-our @EXPORT_OK                 = @EXPORT_LIST;
-our $VERSION                   = '0.39';
-use constant ARG_PLACE_HOLDER => {};
 
-_wrap_to_use_partials(
-    grep { $_ !~ /flow|flow_right|partial|chain|range/ } @EXPORT_LIST
-);
+our $VERSION = '0.31';
+
+use constant ARG_PLACE_HOLDER => {};
 
 # -----------------------------------------------------------------------------#
 
 sub __ { ARG_PLACE_HOLDER };
 
-sub _contains_placeholders {
-    my $arguments = [@_];
-
-    foreach my $arg (@{ $arguments }) {
-        if (ref($arg) and ref(__) and $arg == __) {
-            return 1;
-        }
-    }
-    return 0;
-}
-
-sub _wrap {
-    no warnings 'redefine';
-    no strict 'refs';
-    my ($methodName, $decorator) = @_;
-    my $module                    = caller;
-    my $fullName                  = "$module"."::"."$methodName";
-    my $wrappedSub                = *{"$fullName"}{CODE};
-
-    *{"$fullName"} = List::Util::reduce {
-       my ($wrappedSub, $decor) = ($a, $b);
-       return $decor->($wrappedSub);
-    } ($wrappedSub, $decorator);
-}
-
-sub _can_use_placeholders {
-    my $func = shift;
-
-    return sub {
-        return _contains_placeholders(@_) ? partial($func, @_) : $func->(@_);
-    }
-}
-
-sub _wrap_to_use_partials {
-    foreach my $func_name (@_) {
-        _wrap($func_name, \&_can_use_placeholders);
-    }
-}
-
 sub noop { return undef }
 
 sub identity {
@@ -149,10 +107,9 @@ sub _is_nonsense_range {
     }
 }
 
-
 sub get {
-    my $key     = shift // 0;
     my $coll    = shift // [];
+    my $key     = shift // 0;
     my $default = shift;
 
     if (is_array($coll)) {
@@ -176,19 +133,19 @@ sub apply {
 }
 
 sub flow {
-    my $funcs = [@_];
+    my $args = [@_];
 
-    if (ref $funcs->[0] ne 'CODE') {
+    if (ref $args->[0] ne 'CODE') {
         return \&noop;
     }
 
     return sub {
-        my $args = [@_];
+        my $seed = shift // \&noop;
 
-        return chain(
-            sub { first($funcs)->(spread($args)) },
-            spread(drop($funcs)),
-        );
+        return List::Util::reduce {
+            my ($accum, $func) = ($a, $b);
+            $func->($accum);
+        } ($seed, spread($args));
     }
 }
 
@@ -499,7 +456,6 @@ sub maps {
     return [@vals];
 }
 
-
 sub reduces {
     my $func           = shift;
     my ($accum, $coll) = spread(_get_reduces_args([@_]));
@@ -539,9 +495,8 @@ sub partial {
 
     return sub {
         my $newArgs = [@_];
-        my $filled_args = _fill_holders([spread($oldArgs)], $newArgs);
-
-        return $func->(spread($filled_args));
+        my $no_placeholder_args = _fill_holders($oldArgs, $newArgs);
+        return $func->(@$no_placeholder_args);
     }
 }
 
@@ -556,7 +511,7 @@ sub _fill_holders {
     for (my $idx = 0; $idx < $old_args_len; $idx++) {
         my $arg = shift @{ $old_args };
 
-        if(_contains_placeholders($arg)) {
+        if (eql($arg, __)) {
             push @{ $filled_args }, (shift @{ $new_args });
         } else {
             push @{ $filled_args }, $arg;
@@ -634,8 +589,6 @@ sub spread {
     return split('', $coll);
 }
 
-# ------------------------------------------------------------------------------
-
 =head1 NAME
 
 Sub::Fp - A Clojure / Python Toolz / Lodash inspired Functional Utility Library
@@ -1180,21 +1133,21 @@ Only works one level deep;
         key1 => 'value1',
     };
 
-    get('key1', $hash);
+    get($hash, 'key1');
 
     # 'value1'
 
 
     my $array = [100, 200, 300]
 
-    get(1, $array);
+    get($array, 1);
 
     # 200
 
 
     my $string = "Hello";
 
-    get(1, $string);
+    get($string, 1);
 
     # e
 
@@ -1205,7 +1158,7 @@ Only works one level deep;
         key1 => 'value1',
     };
 
-    get('key2', $hash, "DEFAULT HERE");
+    get($hash, 'key2', "DEFAULT HERE");
 
     # 'DEFAULT HERE'
 
